summaryrefslogtreecommitdiffstats
path: root/chromeos/login/auth/cryptohome_authenticator.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromeos/login/auth/cryptohome_authenticator.h')
-rw-r--r--chromeos/login/auth/cryptohome_authenticator.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chromeos/login/auth/cryptohome_authenticator.h b/chromeos/login/auth/cryptohome_authenticator.h
index d767bd9..cfac3d3 100644
--- a/chromeos/login/auth/cryptohome_authenticator.h
+++ b/chromeos/login/auth/cryptohome_authenticator.h
@@ -129,12 +129,12 @@ class CHROMEOS_EXPORT CryptohomeAuthenticator
// success/failure.
void LoginAsPublicSession(const UserContext& user_context) override;
// Initiates login into the kiosk mode account identified by |app_user_id|.
// Mounts an ephemeral guest cryptohome if |use_guest_mount| is |true|.
// Otherwise, mounts a public cryptohome, which will be ephemeral if the
// |DeviceEphemeralUsersEnabled| policy is enabled and non-ephemeral
// otherwise.
- void LoginAsKioskAccount(const std::string& app_user_id,
+ void LoginAsKioskAccount(const AccountId& app_account_id,
bool use_guest_mount) override;
// These methods must be called on the UI thread, as they make DBus calls
@@ -129,12 +129,12 @@ class CHROMEOS_EXPORT CryptohomeAuthenticator
// success/failure.
void LoginAsPublicSession(const UserContext& user_context) override;
- // Initiates login into the kiosk mode account identified by |app_user_id|.
+ // Initiates login into the kiosk mode account identified by |app_account_id|.
// Mounts an ephemeral guest cryptohome if |use_guest_mount| is |true|.
// Otherwise, mounts a public cryptohome, which will be ephemeral if the